@@ -8,19 +8,16 @@ from .assaydata import AssayDataPage, AssayDataset, AssayMetadata
 
 # workflow system
 from .futures import Future, MappedFuture, StreamingFuture
-from .train import CVFuture, TrainFuture
-from .predict import PredictionResultFuture as WorkflowPredictionResultFuture
-from .design import DesignFuture as WorkflowDesignFuture
 
 # poet system
 from .align import MSAFuture, PromptFuture
-from .deprecated.poet import PoetGenerateFuture, PoetScoreFuture, PoetSingleSiteFuture
 
 # distributed system
 from .embeddings import (
     EmbeddingModel,
-    EmbeddingResultFuture,
-    EmbeddingsScoreResultFuture,
+    EmbeddingsResultFuture,
+    EmbeddingsScoreFuture,
+    EmbeddingsGenerateFuture,
     ESMModel,
     OpenProteinModel,
     PoETModel,
@@ -30,3 +27,5 @@ from .umap import UMAPModel
 from .fold import AlphaFold2Model, ESMFoldModel, FoldModel, FoldResultFuture
 from .predictor import PredictionResultFuture, PredictorModel
 from .designer import DesignFuture
+
+from .deprecated import *
